SDIF Library Download

# SDIFTM Library Download

Copyright (C) 1997-2000 Analyse/Synthèse

### SDIF Library

You can download of the free, open-source IRCAM SDIF library from the download directory. There are source and binary distributions available, and a copy of this documentation site. See the files README and INSTALL in the distribution for how to compile and install.

The source distribution compiles automatically and has been tested on all operating systems where `configure` is available, i.e. all flavours of Unix and BeOS. It compiles on Windows and Macintosh, but you might have to tweak the makefiles or set up your own compiler project. There is a special source distribution for Macintosh with CodeWarrior Pro 5 available.

The binary distribution is available for Linux/PC, SGI, and Macintosh (as a DLL and with header files).

### SDIF Extension for Matlab

Described in this ICMC 2000 article.

Download the latest distribution from the download directory containing mex-files for Linux/PC and DEC Alpha, and `.m` files with documentation and support functions. The mex-files are linked statically, so you don't have to download and install the SDIF library for using them. You could do it anyway to get the utilities...

### Download Directory

http://www.ircam.fr/anasyn/sdif/download

### Support

Use the mailing list sdif@ircam.fr for questions and suggestions.